@@ -9,45 +9,39 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import Optional
 
-# Centralized provider mappings for easy maintenance
-PROVIDER_MAPPING = {
-    "aws_bedrock": "Aws",
-    "openai": "ChatGPT",
-    "anthropic": "Anthropic",
-    "google_ai": "Gemini",
-    "vertex_ai": "VertexAI",
-    "azure_openai": "Azure",
-}
-
-# Environment variable mapping for each provider
-ENV_VAR_MAPPING = {
+# BAML provider mapping for dynamic client creation
+BAML_PROVIDER_MAPPING = {
     "aws_bedrock": {
-        "AWS_ACCESS_KEY_ID": "access_key_id",
-        "AWS_SECRET_ACCESS_KEY": "secret_access_key",
-        "AWS_MODEL_ID": "model_id",
-        "AWS_REGION": "region",
-    },
-    "openai": {
-        "OPENAI_API_KEY": "api_key",
-        "OPENAI_MODEL_ID": "model_id",
+        "provider": "aws-bedrock",
+        "client_name": "AwsBedrock",
     },
     "anthropic": {
-        "ANTHROPIC_API_KEY": "api_key",
-        "ANTHROPIC_MODEL_ID": "model_id",
+        "provider": "anthropic",
+        "client_name": "AnthropicClaude",
+    },
+    "openai": {
+        "provider": "openai",
+        "client_name": "OpenAIChatGPT",
     },
     "google_ai": {
-        "GEMINI_API_KEY": "api_key",
-        "GEMINI_MODEL_ID": "model_id",
-        "GEMINI_BASE_URL": "base_url",
+        "provider": "google-ai",
+        "client_name": "GoogleGemini",
     },
     "vertex_ai": {
-        "GCP_LOCATION": "location",
-        "GCP_MODEL_ID": "model_id",
+        "provider": "vertex-ai",
+        "client_name": "GCPVertexAI",
     },
     "azure_openai": {
-        "AZURE_OPENAI_API_KEY": "api_key",
-        "AZURE_BASE_URL": "base_url",
-        "AZURE_API_VERSION": "api_version",
+        "provider": "azure-openai",
+        "client_name": "AzureOpenAI",
+    },
+    "azure_aifoundry": {
+        "provider": "openai-generic",
+        "client_name": "AzureAIFoundry",
+    },
+    "openrouter": {
+        "provider": "openai-generic",
+        "client_name": "OpenRouter",
     },
 }
 
@@ -83,6 +77,16 @@ PROVIDER_INFO = [
         "key": "openai",
         "description": "ChatGPT models via OpenAI API",
     },
+    {
+        "name": "Azure AI Foundry",
+        "key": "azure_aifoundry",
+        "description": "All supported models on Azure AI Foundry client",
+    },
+    {
+        "name": "OpenRouter",
+        "key": "openrouter",
+        "description": "All supported models on OpenRouter client",
+    },
 ]
 
 
@@ -110,6 +114,7 @@ class AWSConfig:
     access_key_id: str
     secret_access_key: str
     region: str
+    max_tokens: str  # Maximum output tokens per response
 
 
 @dataclass
@@ -118,6 +123,7 @@ class AnthropicConfig:
 
     api_key: str
     model_id: str
+    max_tokens: str  # Maximum output tokens per response
 
 
 @dataclass
@@ -126,23 +132,26 @@ class OpenAIConfig:
 
     api_key: str
     model_id: str
+    max_tokens: str  # Maximum output tokens per response
 
 
 @dataclass
 class GeminiConfig:
-    """Gemini configuration."""
+    """Google Gemini configuration."""
 
     api_key: str
     model_id: str
+    max_tokens: str  # Maximum output tokens per response
     base_url: str = ""  # Optional base URL
 
 
 @dataclass
 class VertexAIConfig:
-    """Vertex AI configuration."""
+    """Google Vertex AI configuration."""
 
     location: str
     model_id: str
+    max_tokens: str  # Maximum output tokens per response
 
 
 @dataclass
@@ -152,6 +161,27 @@ class AzureConfig:
     api_key: str
     base_url: str
     api_version: str
+    max_tokens: str  # Maximum output tokens per response
+
+
+@dataclass
+class AzureAIFoundryConfig:
+    """Azure AI Foundry configuration."""
+
+    api_key: str
+    base_url: str
+    max_tokens: str  # Maximum output tokens per response
+
+
+@dataclass
+class OpenRouterConfig:
+    """OpenRouter configuration."""
+
+    api_key: str
+    model_id: str
+    max_tokens: str  # Maximum output tokens per response
+    http_referer: str = ""  # Optional
+    x_title: str = ""  # Optional
 
 
 @dataclass
@@ -159,6 +189,7 @@ class SuperLLMConfig:
     """SuperLLM configuration."""
 
     api_endpoint: str
+    max_tokens: str  # Maximum output tokens per response
     firebase_token: str = ""  # Optional - will use token manager if empty
     default_model: str = "gpt-3.5-turbo"
     default_provider: str = "openai"
@@ -168,13 +199,15 @@ class SuperLLMConfig:
 class LLMConfig:
     """LLM provider configuration."""
 
-    provider: str  # Options: "anthropic", "superllm", "openai", "vertex_ai", "azure_openai", "google_ai", "aws_bedrock"
+    provider: str  # Options: "anthropic", "superllm", "openai", "vertex_ai", "azure_openai", "google_ai", "aws_bedrock", "azure_aifoundry", "openrouter"
     aws_bedrock: AWSConfig
     anthropic: AnthropicConfig
     openai: OpenAIConfig
     google_ai: GeminiConfig
     vertex_ai: VertexAIConfig
     azure_openai: AzureConfig
+    azure_aifoundry: AzureAIFoundryConfig
+    openrouter: OpenRouterConfig
     superllm: SuperLLMConfig
 
 
@@ -332,6 +365,8 @@ class Config:
                 gemini_config = llm_config.get("google_ai", {})
                 vertex_ai_config = llm_config.get("vertex_ai", {})
                 azure_config = llm_config.get("azure_openai", {})
+                azure_aifoundry_config = llm_config.get("azure_aifoundry", {})
+                openrouter_config = llm_config.get("openrouter", {})
                 superllm_config = llm_config.get("superllm", {})
                 self.llm = LLMConfig(
                     provider=llm_config.get("provider", "openai"),
@@ -351,6 +386,16 @@ class Config:
                     azure_openai=(
                         AzureConfig(**azure_config) if azure_config else None
                     ),
+                    azure_aifoundry=(
+                        AzureAIFoundryConfig(**azure_aifoundry_config)
+                        if azure_aifoundry_config
+                        else None
+                    ),
+                    openrouter=(
+                        OpenRouterConfig(**openrouter_config)
+                        if openrouter_config
+                        else None
+                    ),
                     superllm=(
                         SuperLLMConfig(**superllm_config) if superllm_config else None
                     ),
@@ -412,14 +457,9 @@ class _ConfigProxy:
 config = _ConfigProxy()
 
 
-def get_provider_mapping() -> dict:
-    """Get the provider mapping dictionary."""
-    return PROVIDER_MAPPING
-
-
-def get_env_var_mapping() -> dict:
-    """Get the environment variable mapping dictionary."""
-    return ENV_VAR_MAPPING
+def get_baml_provider_mapping() -> dict:
+    """Get the BAML provider mapping dictionary for dynamic client creation."""
+    return BAML_PROVIDER_MAPPING
 
 
 def get_provider_info() -> list:
@@ -429,9 +469,9 @@ def get_provider_info() -> list:
 
 def get_available_providers() -> list:
     """Get list of available provider keys."""
-    return list(PROVIDER_MAPPING.keys())
+    return list(BAML_PROVIDER_MAPPING.keys())
 
 
 def is_provider_supported(provider: str) -> bool:
     """Check if a provider is supported."""
-    return provider.lower() in PROVIDER_MAPPING
+    return provider.lower() in BAML_PROVIDER_MAPPING
